#ifndef NT2_INCLUDE_CONSTANTS_PI_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_PI_HPP_INCLUDED

#include <nt2/constant/include/constants/pi.hpp>

#endif
